VisitCommand class

Inheritance

Constructors

VisitCommand(StringExpression target)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target → StringExpression
final

Methods

execute(DialogueRunner dialogue) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processInDialogueRunner(DialogueRunner dialogueRunner) Future<void>
Runs the entry within the context of a dialogue runner.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited